# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ServerCommand.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ServerCommand.proto',
  package='opentera.protobuf',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x13ServerCommand.proto\x12\x11opentera.protobuf\x1a\x19google/protobuf/any.proto\"\xa8\x01\n\rServerCommand\x12:\n\x04type\x18\x01 \x01(\x0e\x32,.opentera.protobuf.ServerCommand.CommandType\x12\"\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\"7\n\x0b\x43ommandType\x12\x0f\n\x0b\x43MD_UNKNOWN\x10\x00\x12\x17\n\x13\x43MD_REGISTER_DEVICE\x10\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_any__pb2.DESCRIPTOR,])



_SERVERCOMMAND_COMMANDTYPE = _descriptor.EnumDescriptor(
  name='CommandType',
  full_name='opentera.protobuf.ServerCommand.CommandType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CMD_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CMD_REGISTER_DEVICE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=183,
  serialized_end=238,
)
_sym_db.RegisterEnumDescriptor(_SERVERCOMMAND_COMMANDTYPE)


_SERVERCOMMAND = _descriptor.Descriptor(
  name='ServerCommand',
  full_name='opentera.protobuf.ServerCommand',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='opentera.protobuf.ServerCommand.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='opentera.protobuf.ServerCommand.data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SERVERCOMMAND_COMMANDTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=70,
  serialized_end=238,
)

_SERVERCOMMAND.fields_by_name['type'].enum_type = _SERVERCOMMAND_COMMANDTYPE
_SERVERCOMMAND.fields_by_name['data'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_SERVERCOMMAND_COMMANDTYPE.containing_type = _SERVERCOMMAND
DESCRIPTOR.message_types_by_name['ServerCommand'] = _SERVERCOMMAND
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ServerCommand = _reflection.GeneratedProtocolMessageType('ServerCommand', (_message.Message,), {
  'DESCRIPTOR' : _SERVERCOMMAND,
  '__module__' : 'ServerCommand_pb2'
  # @@protoc_insertion_point(class_scope:opentera.protobuf.ServerCommand)
  })
_sym_db.RegisterMessage(ServerCommand)


# @@protoc_insertion_point(module_scope)
