# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: UserEvent.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='UserEvent.proto',
  package='opentera.protobuf',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0fUserEvent.proto\x12\x11opentera.protobuf\"\x9a\x02\n\tUserEvent\x12\x11\n\tuser_uuid\x18\x01 \x01(\t\x12\x34\n\x04type\x18\x02 \x01(\x0e\x32&.opentera.protobuf.UserEvent.EventType\x12\x15\n\ruser_fullname\x18\x03 \x01(\t\"\xac\x01\n\tEventType\x12\x10\n\x0cUSER_UNKNOWN\x10\x00\x12\x12\n\x0eUSER_CONNECTED\x10\x01\x12\x15\n\x11USER_DISCONNECTED\x10\x02\x12\x10\n\x0cUSER_DELETED\x10\x03\x12\x0e\n\nUSER_ADDED\x10\x04\x12\x10\n\x0cUSER_UPDATED\x10\x05\x12\x17\n\x13USER_JOINED_SESSION\x10\x06\x12\x15\n\x11USER_LEFT_SESSION\x10\x07\x62\x06proto3'
)



_USEREVENT_EVENTTYPE = _descriptor.EnumDescriptor(
  name='EventType',
  full_name='opentera.protobuf.UserEvent.EventType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='USER_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='USER_CONNECTED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='USER_DISCONNECTED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='USER_DELETED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='USER_ADDED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='USER_UPDATED', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='USER_JOINED_SESSION', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='USER_LEFT_SESSION', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=149,
  serialized_end=321,
)
_sym_db.RegisterEnumDescriptor(_USEREVENT_EVENTTYPE)


_USEREVENT = _descriptor.Descriptor(
  name='UserEvent',
  full_name='opentera.protobuf.UserEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_uuid', full_name='opentera.protobuf.UserEvent.user_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='opentera.protobuf.UserEvent.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_fullname', full_name='opentera.protobuf.UserEvent.user_fullname', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _USEREVENT_EVENTTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=39,
  serialized_end=321,
)

_USEREVENT.fields_by_name['type'].enum_type = _USEREVENT_EVENTTYPE
_USEREVENT_EVENTTYPE.containing_type = _USEREVENT
DESCRIPTOR.message_types_by_name['UserEvent'] = _USEREVENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UserEvent = _reflection.GeneratedProtocolMessageType('UserEvent', (_message.Message,), {
  'DESCRIPTOR' : _USEREVENT,
  '__module__' : 'UserEvent_pb2'
  # @@protoc_insertion_point(class_scope:opentera.protobuf.UserEvent)
  })
_sym_db.RegisterMessage(UserEvent)


# @@protoc_insertion_point(module_scope)
