# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: JoinSessionReplyEvent.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='JoinSessionReplyEvent.proto',
  package='opentera.protobuf',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1bJoinSessionReplyEvent.proto\x12\x11opentera.protobuf\"\xb3\x02\n\x15JoinSessionReplyEvent\x12\x14\n\x0csession_uuid\x18\x01 \x01(\t\x12\x11\n\tuser_uuid\x18\x02 \x01(\t\x12\x18\n\x10participant_uuid\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65vice_uuid\x18\x04 \x01(\t\x12\x46\n\njoin_reply\x18\x05 \x01(\x0e\x32\x32.opentera.protobuf.JoinSessionReplyEvent.ReplyType\x12\x11\n\treply_msg\x18\x06 \x01(\t\"g\n\tReplyType\x12\x11\n\rREPLY_UNKNOWN\x10\x00\x12\x12\n\x0eREPLY_ACCEPTED\x10\x01\x12\x10\n\x0cREPLY_DENIED\x10\x02\x12\x0e\n\nREPLY_BUSY\x10\x03\x12\x11\n\rREPLY_TIMEOUT\x10\x04\x62\x06proto3'
)



_JOINSESSIONREPLYEVENT_REPLYTYPE = _descriptor.EnumDescriptor(
  name='ReplyType',
  full_name='opentera.protobuf.JoinSessionReplyEvent.ReplyType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='REPLY_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REPLY_ACCEPTED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REPLY_DENIED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REPLY_BUSY', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REPLY_TIMEOUT', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=255,
  serialized_end=358,
)
_sym_db.RegisterEnumDescriptor(_JOINSESSIONREPLYEVENT_REPLYTYPE)


_JOINSESSIONREPLYEVENT = _descriptor.Descriptor(
  name='JoinSessionReplyEvent',
  full_name='opentera.protobuf.JoinSessionReplyEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_uuid', full_name='opentera.protobuf.JoinSessionReplyEvent.session_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_uuid', full_name='opentera.protobuf.JoinSessionReplyEvent.user_uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='participant_uuid', full_name='opentera.protobuf.JoinSessionReplyEvent.participant_uuid', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_uuid', full_name='opentera.protobuf.JoinSessionReplyEvent.device_uuid', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='join_reply', full_name='opentera.protobuf.JoinSessionReplyEvent.join_reply', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reply_msg', full_name='opentera.protobuf.JoinSessionReplyEvent.reply_msg', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _JOINSESSIONREPLYEVENT_REPLYTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=51,
  serialized_end=358,
)

_JOINSESSIONREPLYEVENT.fields_by_name['join_reply'].enum_type = _JOINSESSIONREPLYEVENT_REPLYTYPE
_JOINSESSIONREPLYEVENT_REPLYTYPE.containing_type = _JOINSESSIONREPLYEVENT
DESCRIPTOR.message_types_by_name['JoinSessionReplyEvent'] = _JOINSESSIONREPLYEVENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

JoinSessionReplyEvent = _reflection.GeneratedProtocolMessageType('JoinSessionReplyEvent', (_message.Message,), {
  'DESCRIPTOR' : _JOINSESSIONREPLYEVENT,
  '__module__' : 'JoinSessionReplyEvent_pb2'
  # @@protoc_insertion_point(class_scope:opentera.protobuf.JoinSessionReplyEvent)
  })
_sym_db.RegisterMessage(JoinSessionReplyEvent)


# @@protoc_insertion_point(module_scope)
