# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: LeaveSessionEvent.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='LeaveSessionEvent.proto',
  package='opentera.protobuf',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x17LeaveSessionEvent.proto\x12\x11opentera.protobuf\"\x8d\x01\n\x11LeaveSessionEvent\x12\x14\n\x0csession_uuid\x18\x01 \x01(\t\x12\x14\n\x0cservice_uuid\x18\x02 \x01(\t\x12\x1c\n\x14leaving_participants\x18\x03 \x03(\t\x12\x15\n\rleaving_users\x18\x04 \x03(\t\x12\x17\n\x0fleaving_devices\x18\x05 \x03(\tb\x06proto3'
)




_LEAVESESSIONEVENT = _descriptor.Descriptor(
  name='LeaveSessionEvent',
  full_name='opentera.protobuf.LeaveSessionEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_uuid', full_name='opentera.protobuf.LeaveSessionEvent.session_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_uuid', full_name='opentera.protobuf.LeaveSessionEvent.service_uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='leaving_participants', full_name='opentera.protobuf.LeaveSessionEvent.leaving_participants', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='leaving_users', full_name='opentera.protobuf.LeaveSessionEvent.leaving_users', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='leaving_devices', full_name='opentera.protobuf.LeaveSessionEvent.leaving_devices', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=47,
  serialized_end=188,
)

DESCRIPTOR.message_types_by_name['LeaveSessionEvent'] = _LEAVESESSIONEVENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LeaveSessionEvent = _reflection.GeneratedProtocolMessageType('LeaveSessionEvent', (_message.Message,), {
  'DESCRIPTOR' : _LEAVESESSIONEVENT,
  '__module__' : 'LeaveSessionEvent_pb2'
  # @@protoc_insertion_point(class_scope:opentera.protobuf.LeaveSessionEvent)
  })
_sym_db.RegisterMessage(LeaveSessionEvent)


# @@protoc_insertion_point(module_scope)
