# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ParticipantEvent.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='ParticipantEvent.proto',
  package='opentera.protobuf',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x16ParticipantEvent.proto\x12\x11opentera.protobuf\"\x92\x03\n\x10ParticipantEvent\x12\x18\n\x10participant_uuid\x18\x01 \x01(\t\x12;\n\x04type\x18\x02 \x01(\x0e\x32-.opentera.protobuf.ParticipantEvent.EventType\x12\x18\n\x10participant_name\x18\x03 \x01(\t\x12 \n\x18participant_project_name\x18\x04 \x01(\t\x12\x1d\n\x15participant_site_name\x18\x05 \x01(\t\"\xcb\x01\n\tEventType\x12\x17\n\x13PARTICIPANT_UNKNOWN\x10\x00\x12\x19\n\x15PARTICIPANT_CONNECTED\x10\x01\x12\x1c\n\x18PARTICIPANT_DISCONNECTED\x10\x02\x12\x17\n\x13PARTICIPANT_DELETED\x10\x03\x12\x15\n\x11PARTICIPANT_ADDED\x10\x04\x12\x1e\n\x1aPARTICIPANT_JOINED_SESSION\x10\x05\x12\x1c\n\x18PARTICIPANT_LEFT_SESSION\x10\x06\x62\x06proto3'
)



_PARTICIPANTEVENT_EVENTTYPE = _descriptor.EnumDescriptor(
  name='EventType',
  full_name='opentera.protobuf.ParticipantEvent.EventType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PARTICIPANT_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARTICIPANT_CONNECTED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARTICIPANT_DISCONNECTED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARTICIPANT_DELETED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARTICIPANT_ADDED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARTICIPANT_JOINED_SESSION', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARTICIPANT_LEFT_SESSION', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=245,
  serialized_end=448,
)
_sym_db.RegisterEnumDescriptor(_PARTICIPANTEVENT_EVENTTYPE)


_PARTICIPANTEVENT = _descriptor.Descriptor(
  name='ParticipantEvent',
  full_name='opentera.protobuf.ParticipantEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='participant_uuid', full_name='opentera.protobuf.ParticipantEvent.participant_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='opentera.protobuf.ParticipantEvent.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='participant_name', full_name='opentera.protobuf.ParticipantEvent.participant_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='participant_project_name', full_name='opentera.protobuf.ParticipantEvent.participant_project_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='participant_site_name', full_name='opentera.protobuf.ParticipantEvent.participant_site_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PARTICIPANTEVENT_EVENTTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=46,
  serialized_end=448,
)

_PARTICIPANTEVENT.fields_by_name['type'].enum_type = _PARTICIPANTEVENT_EVENTTYPE
_PARTICIPANTEVENT_EVENTTYPE.containing_type = _PARTICIPANTEVENT
DESCRIPTOR.message_types_by_name['ParticipantEvent'] = _PARTICIPANTEVENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ParticipantEvent = _reflection.GeneratedProtocolMessageType('ParticipantEvent', (_message.Message,), {
  'DESCRIPTOR' : _PARTICIPANTEVENT,
  '__module__' : 'ParticipantEvent_pb2'
  # @@protoc_insertion_point(class_scope:opentera.protobuf.ParticipantEvent)
  })
_sym_db.RegisterMessage(ParticipantEvent)


# @@protoc_insertion_point(module_scope)
