# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: LogEvent.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='LogEvent.proto',
  package='opentera.protobuf',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0eLogEvent.proto\x12\x11opentera.protobuf\"\xa6\x02\n\x08LogEvent\x12\x33\n\x05level\x18\x01 \x01(\x0e\x32$.opentera.protobuf.LogEvent.LogLevel\x12\x11\n\ttimestamp\x18\x02 \x01(\x01\x12\x0e\n\x06sender\x18\x03 \x01(\t\x12\x0f\n\x07message\x18\x04 \x01(\t\"\xb0\x01\n\x08LogLevel\x12\x14\n\x10LOGLEVEL_UNKNOWN\x10\x00\x12\x12\n\x0eLOGLEVEL_TRACE\x10\x07\x12\x12\n\x0eLOGLEVEL_DEBUG\x10\x06\x12\x11\n\rLOGLEVEL_INFO\x10\x05\x12\x14\n\x10LOGLEVEL_WARNING\x10\x04\x12\x15\n\x11LOGLEVEL_CRITICAL\x10\x03\x12\x12\n\x0eLOGLEVEL_ERROR\x10\x02\x12\x12\n\x0eLOGLEVEL_FATAL\x10\x01\x62\x06proto3'
)



_LOGEVENT_LOGLEVEL = _descriptor.EnumDescriptor(
  name='LogLevel',
  full_name='opentera.protobuf.LogEvent.LogLevel',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LOGLEVEL_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOGLEVEL_TRACE', index=1, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOGLEVEL_DEBUG', index=2, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOGLEVEL_INFO', index=3, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOGLEVEL_WARNING', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOGLEVEL_CRITICAL', index=5, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOGLEVEL_ERROR', index=6, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOGLEVEL_FATAL', index=7, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=156,
  serialized_end=332,
)
_sym_db.RegisterEnumDescriptor(_LOGEVENT_LOGLEVEL)


_LOGEVENT = _descriptor.Descriptor(
  name='LogEvent',
  full_name='opentera.protobuf.LogEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='level', full_name='opentera.protobuf.LogEvent.level', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='opentera.protobuf.LogEvent.timestamp', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sender', full_name='opentera.protobuf.LogEvent.sender', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='opentera.protobuf.LogEvent.message', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LOGEVENT_LOGLEVEL,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=38,
  serialized_end=332,
)

_LOGEVENT.fields_by_name['level'].enum_type = _LOGEVENT_LOGLEVEL
_LOGEVENT_LOGLEVEL.containing_type = _LOGEVENT
DESCRIPTOR.message_types_by_name['LogEvent'] = _LOGEVENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LogEvent = _reflection.GeneratedProtocolMessageType('LogEvent', (_message.Message,), {
  'DESCRIPTOR' : _LOGEVENT,
  '__module__' : 'LogEvent_pb2'
  # @@protoc_insertion_point(class_scope:opentera.protobuf.LogEvent)
  })
_sym_db.RegisterMessage(LogEvent)


# @@protoc_insertion_point(module_scope)
