# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: DeviceEvent.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='DeviceEvent.proto',
  package='opentera.protobuf',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x11\x44\x65viceEvent.proto\x12\x11opentera.protobuf\"\xcc\x02\n\x0b\x44\x65viceEvent\x12\x13\n\x0b\x64\x65vice_uuid\x18\x01 \x01(\t\x12\x36\n\x04type\x18\x02 \x01(\x0e\x32(.opentera.protobuf.DeviceEvent.EventType\x12\x13\n\x0b\x64\x65vice_name\x18\x03 \x01(\t\x12\x15\n\rdevice_status\x18\x04 \x01(\t\"\xc3\x01\n\tEventType\x12\x12\n\x0e\x44\x45VICE_UNKNOWN\x10\x00\x12\x14\n\x10\x44\x45VICE_CONNECTED\x10\x01\x12\x17\n\x13\x44\x45VICE_DISCONNECTED\x10\x02\x12\x12\n\x0e\x44\x45VICE_DELETED\x10\x03\x12\x10\n\x0c\x44\x45VICE_ADDED\x10\x04\x12\x19\n\x15\x44\x45VICE_JOINED_SESSION\x10\x05\x12\x17\n\x13\x44\x45VICE_LEFT_SESSION\x10\x06\x12\x19\n\x15\x44\x45VICE_STATUS_CHANGED\x10\x07\x62\x06proto3'
)



_DEVICEEVENT_EVENTTYPE = _descriptor.EnumDescriptor(
  name='EventType',
  full_name='opentera.protobuf.DeviceEvent.EventType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DEVICE_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEVICE_CONNECTED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEVICE_DISCONNECTED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEVICE_DELETED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEVICE_ADDED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEVICE_JOINED_SESSION', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEVICE_LEFT_SESSION', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEVICE_STATUS_CHANGED', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=178,
  serialized_end=373,
)
_sym_db.RegisterEnumDescriptor(_DEVICEEVENT_EVENTTYPE)


_DEVICEEVENT = _descriptor.Descriptor(
  name='DeviceEvent',
  full_name='opentera.protobuf.DeviceEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_uuid', full_name='opentera.protobuf.DeviceEvent.device_uuid', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='opentera.protobuf.DeviceEvent.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_name', full_name='opentera.protobuf.DeviceEvent.device_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_status', full_name='opentera.protobuf.DeviceEvent.device_status', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DEVICEEVENT_EVENTTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=41,
  serialized_end=373,
)

_DEVICEEVENT.fields_by_name['type'].enum_type = _DEVICEEVENT_EVENTTYPE
_DEVICEEVENT_EVENTTYPE.containing_type = _DEVICEEVENT
DESCRIPTOR.message_types_by_name['DeviceEvent'] = _DEVICEEVENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DeviceEvent = _reflection.GeneratedProtocolMessageType('DeviceEvent', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEEVENT,
  '__module__' : 'DeviceEvent_pb2'
  # @@protoc_insertion_point(class_scope:opentera.protobuf.DeviceEvent)
  })
_sym_db.RegisterMessage(DeviceEvent)


# @@protoc_insertion_point(module_scope)
