# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: TeraMessage.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='TeraMessage.proto',
  package='opentera.protobuf',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x11TeraMessage.proto\x12\x11opentera.protobuf\x1a\x19google/protobuf/any.proto\"4\n\x0bTeraMessage\x12%\n\x07message\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Anyb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_any__pb2.DESCRIPTOR,])




_TERAMESSAGE = _descriptor.Descriptor(
  name='TeraMessage',
  full_name='opentera.protobuf.TeraMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='opentera.protobuf.TeraMessage.message', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=67,
  serialized_end=119,
)

_TERAMESSAGE.fields_by_name['message'].message_type = google_dot_protobuf_dot_any__pb2._ANY
DESCRIPTOR.message_types_by_name['TeraMessage'] = _TERAMESSAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TeraMessage = _reflection.GeneratedProtocolMessageType('TeraMessage', (_message.Message,), {
  'DESCRIPTOR' : _TERAMESSAGE,
  '__module__' : 'TeraMessage_pb2'
  # @@protoc_insertion_point(class_scope:opentera.protobuf.TeraMessage)
  })
_sym_db.RegisterMessage(TeraMessage)


# @@protoc_insertion_point(module_scope)
