# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: DatabaseEvent.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='DatabaseEvent.proto',
  package='opentera.protobuf',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x13\x44\x61tabaseEvent.proto\x12\x11opentera.protobuf\"\xbe\x01\n\rDatabaseEvent\x12\x38\n\x04type\x18\x01 \x01(\x0e\x32*.opentera.protobuf.DatabaseEvent.EventType\x12\x13\n\x0bobject_type\x18\x02 \x01(\t\x12\x14\n\x0cobject_value\x18\x03 \x01(\t\"H\n\tEventType\x12\x0e\n\nDB_UNKNOWN\x10\x00\x12\r\n\tDB_CREATE\x10\x01\x12\r\n\tDB_UPDATE\x10\x02\x12\r\n\tDB_DELETE\x10\x03\x62\x06proto3'
)



_DATABASEEVENT_EVENTTYPE = _descriptor.EnumDescriptor(
  name='EventType',
  full_name='opentera.protobuf.DatabaseEvent.EventType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DB_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DB_CREATE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DB_UPDATE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DB_DELETE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=161,
  serialized_end=233,
)
_sym_db.RegisterEnumDescriptor(_DATABASEEVENT_EVENTTYPE)


_DATABASEEVENT = _descriptor.Descriptor(
  name='DatabaseEvent',
  full_name='opentera.protobuf.DatabaseEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='opentera.protobuf.DatabaseEvent.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='object_type', full_name='opentera.protobuf.DatabaseEvent.object_type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='object_value', full_name='opentera.protobuf.DatabaseEvent.object_value', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DATABASEEVENT_EVENTTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=43,
  serialized_end=233,
)

_DATABASEEVENT.fields_by_name['type'].enum_type = _DATABASEEVENT_EVENTTYPE
_DATABASEEVENT_EVENTTYPE.containing_type = _DATABASEEVENT
DESCRIPTOR.message_types_by_name['DatabaseEvent'] = _DATABASEEVENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DatabaseEvent = _reflection.GeneratedProtocolMessageType('DatabaseEvent', (_message.Message,), {
  'DESCRIPTOR' : _DATABASEEVENT,
  '__module__' : 'DatabaseEvent_pb2'
  # @@protoc_insertion_point(class_scope:opentera.protobuf.DatabaseEvent)
  })
_sym_db.RegisterMessage(DatabaseEvent)


# @@protoc_insertion_point(module_scope)
