# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: UserRegisterToEvent.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='UserRegisterToEvent.proto',
  package='opentera.protobuf',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x19UserRegisterToEvent.proto\x12\x11opentera.protobuf\"\xa9\x05\n\x13UserRegisterToEvent\x12\x44\n\nevent_type\x18\x01 \x01(\x0e\x32\x30.opentera.protobuf.UserRegisterToEvent.EventType\x12=\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32-.opentera.protobuf.UserRegisterToEvent.Action\"\xc2\x03\n\tEventType\x12\x11\n\rEVENT_UNKNOWN\x10\x00\x12\x18\n\x14\x45VENT_USER_CONNECTED\x10\x01\x12\x1b\n\x17\x45VENT_USER_DISCONNECTED\x10\x02\x12\x16\n\x12\x45VENT_USER_DELETED\x10\x03\x12\x14\n\x10\x45VENT_USER_ADDED\x10\x04\x12\x16\n\x12\x45VENT_USER_UPDATED\x10\x05\x12\x1f\n\x1b\x45VENT_PARTICIPANT_CONNECTED\x10\x06\x12\"\n\x1e\x45VENT_PARTICIPANT_DISCONNECTED\x10\x07\x12\x1d\n\x19\x45VENT_PARTICIPANT_DELETED\x10\x08\x12\x1b\n\x17\x45VENT_PARTICIPANT_ADDED\x10\t\x12\x1d\n\x19\x45VENT_PARTICIPANT_UPDATED\x10\n\x12\x1a\n\x16\x45VENT_DEVICE_CONNECTED\x10\x0b\x12\x1d\n\x19\x45VENT_DEVICE_DISCONNECTED\x10\x0c\x12\x18\n\x14\x45VENT_DEVICE_DELETED\x10\r\x12\x16\n\x12\x45VENT_DEVICE_ADDED\x10\x0e\x12\x18\n\x14\x45VENT_DEVICE_UPDATED\x10\x0f\"H\n\x06\x41\x63tion\x12\x12\n\x0e\x41\x43TION_UNKNOWN\x10\x00\x12\x13\n\x0f\x41\x43TION_REGISTER\x10\x01\x12\x15\n\x11\x41\x43TION_UNREGISTER\x10\x02\x62\x06proto3'
)



_USERREGISTERTOEVENT_EVENTTYPE = _descriptor.EnumDescriptor(
  name='EventType',
  full_name='opentera.protobuf.UserRegisterToEvent.EventType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EVENT_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EVENT_USER_CONNECTED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EVENT_USER_DISCONNECTED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EVENT_USER_DELETED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EVENT_USER_ADDED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EVENT_USER_UPDATED', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EVENT_PARTICIPANT_CONNECTED', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EVENT_PARTICIPANT_DISCONNECTED', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EVENT_PARTICIPANT_DELETED', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EVENT_PARTICIPANT_ADDED', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EVENT_PARTICIPANT_UPDATED', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EVENT_DEVICE_CONNECTED', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EVENT_DEVICE_DISCONNECTED', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EVENT_DEVICE_DELETED', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EVENT_DEVICE_ADDED', index=14, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EVENT_DEVICE_UPDATED', index=15, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=206,
  serialized_end=656,
)
_sym_db.RegisterEnumDescriptor(_USERREGISTERTOEVENT_EVENTTYPE)

_USERREGISTERTOEVENT_ACTION = _descriptor.EnumDescriptor(
  name='Action',
  full_name='opentera.protobuf.UserRegisterToEvent.Action',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ACTION_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTION_REGISTER', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTION_UNREGISTER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=658,
  serialized_end=730,
)
_sym_db.RegisterEnumDescriptor(_USERREGISTERTOEVENT_ACTION)


_USERREGISTERTOEVENT = _descriptor.Descriptor(
  name='UserRegisterToEvent',
  full_name='opentera.protobuf.UserRegisterToEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_type', full_name='opentera.protobuf.UserRegisterToEvent.event_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='action', full_name='opentera.protobuf.UserRegisterToEvent.action', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _USERREGISTERTOEVENT_EVENTTYPE,
    _USERREGISTERTOEVENT_ACTION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=49,
  serialized_end=730,
)

_USERREGISTERTOEVENT.fields_by_name['event_type'].enum_type = _USERREGISTERTOEVENT_EVENTTYPE
_USERREGISTERTOEVENT.fields_by_name['action'].enum_type = _USERREGISTERTOEVENT_ACTION
_USERREGISTERTOEVENT_EVENTTYPE.containing_type = _USERREGISTERTOEVENT
_USERREGISTERTOEVENT_ACTION.containing_type = _USERREGISTERTOEVENT
DESCRIPTOR.message_types_by_name['UserRegisterToEvent'] = _USERREGISTERTOEVENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UserRegisterToEvent = _reflection.GeneratedProtocolMessageType('UserRegisterToEvent', (_message.Message,), {
  'DESCRIPTOR' : _USERREGISTERTOEVENT,
  '__module__' : 'UserRegisterToEvent_pb2'
  # @@protoc_insertion_point(class_scope:opentera.protobuf.UserRegisterToEvent)
  })
_sym_db.RegisterMessage(UserRegisterToEvent)


# @@protoc_insertion_point(module_scope)
